@@ -21,3 +21,12 @@ noprimes = to_vec(for (i in 2:7) for (j in seq(i*2, 99, i)) j)
 primes = to_vec(for (x in 2:99) if(!x %in% noprimes) x)
 primes
 
+## ------------------------------------------------------------------------
+to_vec(for(`i, j` in numerate(letters)) if(i %% 2==0) paste(i, j))
+
+set.seed(123)
+rand_sequence = runif(20)
+# gives only locally increasing values
+to_vec(for(`i, j` in lag_list(rand_sequence)) if(j>i) j)
+
+
